@@ -1,6 +1,7 @@
 __author__ = 'gsibble'
 
 from base_types import SDFirstClassObject
+from sd_menu_item import SDMenuItem
 
 class SDMenu(SDFirstClassObject):
 
@@ -30,15 +31,19 @@ class SDMenu(SDFirstClassObject):
         self._category_id_dict = {}
 
         for category in swagger_menu:
+
+            #Store the items
+            for index, item in enumerate(category.items):
+                setattr(item, 'category', category.category_name)
+                sd_item = SDMenuItem(parent=self, location=self._location, swagger_menu_item=item, use_cache=self._use_cache)
+                self.items.append(sd_item)
+                self._item_name_dict[item.name] = sd_item
+                self._item_id_dict[item.item_id] = sd_item
+                category.items[index] = sd_item
+                
             self._category_name_dict[category.category_name] = category
             self._category_id_dict[category.category_id] = category
 
-            #Store the items
-            for item in category.items:
-                setattr(item, 'category', category.category_name)
-                self.items.append(item)
-                self._item_name_dict[item.name] = item
-                self._item_id_dict[item.item_id] = item
 
     def get_category(self, category_id=None, category_name=None):
 
